(Uncleprofilek) ตัวอย่างอัพโหลด
===============================

PyPi: https://pypi.org/project/uncleprofilek/

ตัวอย่าง

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install uncleprofilek

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   my = Profile('Loong')
       my.company = 'uncle-engineer'
       my.hobby = ['Youtuber','Reading','Sleeping']
       print(my.name)
       my.show_email()
       my.show_myart()
       my.show_hobby()
       my.show_cat()

FB: https://www.facebook.com/kanapoj.sirisant

YouTube: https://www.youtube.com/UncleEngineer
